from camiseta.tempfile import *

class Html:
    def __init__(self, ignore_doctype = False):
        self.ignore_doctype = ignore_doctype

    def __enter__(self):
        self.prefix = ''
        if not self.ignore_doctype:
            self.prefix = '<!DOCTYPE html>'
        temp_file.write('{}<html>'.format(self.prefix))

    def __exit__(self, type, value, traceback):
        temp_file.write('</html>')

class Head:
    def __enter__(self):
        temp_file.write('<head>')

    def __exit__(self, type, value, traceback):
        temp_file.write('</head>')

class Style:
    def __enter__(self):
        temp_file.write('<style>')

    def __exit__(self, type, value, traceback):
        temp_file.write('</style>')

class Body:
    def __enter__(self):
        temp_file.write('<body>')

    def __exit__(self, type, value, traceback):
        temp_file.write('</body>')

class Tag:
    def __init__(self, tag, Class = '', id = '', props = ''):
        self.tag = tag
        self.attr_class = Class
        self.attr_id = id
        self.props = props
        
        if self.attr_id != '': self.attr_id = 'id="{}"'.format(self.attr_id)
        if self.attr_class != '': self.attr_class = 'class="{}"'.format(self.attr_class)
    
    def __enter__(self):
        temp_file.write('<{} {} {} {}>'.format(self.tag,self.attr_id, self.attr_class, self.props))

    def __exit__(self, type, value, traceback):
        temp_file.write('</{}>'.format(self.tag))

class Img:
    def __init__(self, src, alt, width = '', height = '', Class = '', id = ''):
        self.src = src
        self.alt = alt
        self. width = width
        self.height = height
        self.attr_class = Class
        self.attr_id = id

        if self.width != '': self.width = 'width="{}"'.format(self.width)
        if self.height != '': self.height = 'height="{}"'.format(self.height)

        if self.attr_id != '': self.attr_id = 'id="{}"'.format(self.attr_id)
        if self.attr_class != '': self.attr_class = 'class="{}"'.format(self.attr_class)

        temp_file.write('<img src="{}" alt="{}" {} {} {} {}>'.format(self.src, self.alt, self.width, self.height, self.attr_id, self.attr_class))

class A:
    def __init__(self, href, target='_blank'):
        self.href = href
        self.target = target

    def __enter__(self):
        temp_file.write('<a href="{}" target="{}">'.format(self.href, self.target))

    def __exit__(self, type, value, traceback):
        temp_file.write('</a>')


from camiseta.tempfile import *

class Meta:
    def __init__(self, prop):
        self.prop = prop
        temp_file.write('<meta {}/>'.format(self.prop))

class Css:
    def __init__(self, attribute, style):
        temp_file.write(attribute + '{' + style + '}')

class Text:
    def __init__(self, text):
        self.text = text
        temp_file.write(self.text)


from camiseta.tempfile import *
import pathlib, os

class Doc:
    def __init__(self, path='', file_name = ''):
        self.path = path
        self.name = file_name

        # Validating path
        if not os.path.isdir(self.path) and self.path != '':
            return print('Invalid output path {}'.format(self.path))
        else:
            if self.path == '': self.path = pathlib.Path().resolve()

        # Validating file name
        if self.name == '': self.name = 'index.html'
        if not self.name.endswith('.html'): self.name += '.html'
        
        temp_file.seek(0)
        with open('{}/{}'.format(self.path, self.name), 'w') as html:
            html.write(temp_file.read())
        temp_file.close()
        print('Finished. {} saved in {}/{}'.format(self.name, self.path, self.name))

class File:
    def __init__(self, path = ''):
        try:
            self.path = os.path.join(pathlib.Path().resolve(), path)
            with open(self.path, 'r') as file:
                temp_file.write(file.read())
        except:
            print('Error loading file {}. Ignoring.'.format(self.path))



from setuptools import setup, find_packages

VERSION = '0.0.2'
DESCRIPTION = 'Framework to generate an html file with python'
LONG_DESCRIPTION = 'Framework to generate an html file with python'

# Setting up
setup(
    name="camiseta",
    version=VERSION,
    author="Adrien (Adrien4g)",
    author_email="<adrien.de.adrien@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'site', 'html', 'frontend', 'camiseta', 'brazil'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
    ]
)